# reflex-antd

A Reflex custom component wrap [ant.design](https://ant.design/).
pypi: [reflex-antd](https://pypi.org/pypi/reflex-antd/)

## Installation

```bash
pip install reflex-antd
```

## antd-demo

[antd-demo](https://antd-demo.reflex.run)


### screen
- table
![table](docs/img/table1.png)
- menu
![menu1](docs/img/menu1.png)
- transfer
![transfer1](docs/img/transfer1.png)
- ...



